import React, { Component } from 'react';
import {
    StyleSheet,
    Text,
    View,
    Platform,
    TabBarIOS,
    Navigator,
    NavigatorIOS,
    DrawerLayoutAndroid,
    ToolbarAndroid,
} from 'react-native';

import Persons from './Persons';
import ContactTypes from './ContactTypes';
import Logout from './Logout';

const icPersons = require('../images/persons.png');
const icContactTypes = require('../images/contactTypes.png');
const icLogout = require('../images/logout.png');

const styles = StyleSheet.create({
    container: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: '#F5FCFF',
    },
    containerToolbar: {
        flex: 1,
        alignItems: 'stretch',
        backgroundColor: '#F5FCFF',
    },
    navigator: {
        flex: 1,
    },
    toolbar: {
        height: 56,
        backgroundColor: '#e9eaed',
    },
});

class AppContainer extends Component {
    constructor(props) {
        super(props);
        this.onLogout = this.onLogout.bind(this);
        this.onToolbarActionSelected = this.onToolbarActionSelected.bind(this);
        this.state = {
            selectedTab: 'persons',
        };
    }

    onLogout() {
        console.log('logout in appcontainer!');
        this.props.onLogout();
    }

    onToolbarActionSelected(position) {
        console.log(position);
        switch (position) {
            case 0:
                this.setState({ selectedTab: 'persons' });
                break;
            case 1:
                this.setState({ selectedTab: 'contactTypes' });
                break;
            case 2:
                this.setState({ selectedTab: 'logout' });
                break;
            default:
                console.log('Unknow toolbar item');
        }
    }

    render() {
        if (Platform.OS === 'ios') {
            return (
                <TabBarIOS style={styles.container}>
                    <TabBarIOS.Item
                        icon={icPersons}
                        onPress = {() => this.setState({ selectedTab: 'persons' }) }
                        selected={this.state.selectedTab === 'persons'}
                        title="Persons">
                        <NavigatorIOS
                            initialRoute={ {
                                component: Persons,
                                title: 'Persons',
                            } }
                            style={styles.navigator}/>
                    </TabBarIOS.Item>
                    <TabBarIOS.Item
                        icon={icContactTypes}
                        onPress = {() => this.setState({ selectedTab: 'contactTypes' }) }
                        selected={this.state.selectedTab === 'contactTypes'}
                        title="Contact Types">
                        <NavigatorIOS
                            initialRoute={ {
                                component: ContactTypes,
                                title: 'Contact Types',
                            } }
                            style={styles.navigator}/>
                    </TabBarIOS.Item>
                    <TabBarIOS.Item
                        icon={icLogout}
                        onPress = {() => this.setState({ selectedTab: 'logout' }) }
                        selected={this.state.selectedTab === 'logout'}
                        title="Logout">
                        <NavigatorIOS
                            initialRoute={ {
                                component: Logout,
                                title: 'Logout',
                                passProps: { onLogout: this.onLogout.bind(this) },
                            } }
                            style={styles.navigator}/>
                    </TabBarIOS.Item>
                </TabBarIOS>
            );
        }
        // Android
        let androidView = <View/>;
        switch (this.state.selectedTab) {
            case 'persons':
                androidView = <Persons/>;
                break;
            case 'contactTypes':
                androidView = <ContactTypes/>;
                break;
            case 'logout':
                androidView = <Logout onLogout={this.onLogout.bind(this) }/>;
                break;
            default:
        }

        return (
            <View style={styles.containerToolbar}>
                <ToolbarAndroid
                    actions={[
                        { title: 'Persons', icon: icPersons, show: 'never', showWithText: true },
                        { title: 'Contact Types', icon: icContactTypes, show: 'never', showWithText: true },
                        { title: 'Logout', icon: icLogout, show: 'never', showWithText: true },
                    ]}
                    onActionSelected={this.onToolbarActionSelected}
                    style={styles.toolbar}
                    title="ContactRN"/>
                {androidView}
            </View>
        );
    }
}

AppContainer.propTypes = {
    // http://ricostacruz.com/cheatsheets/react.html
    onLogout: React.PropTypes.func,
};

module.exports = AppContainer;
