import React, { Component } from 'react';
import {
    ActivityIndicator,
    Image,
    StyleSheet,
    Text,
    TextInput,
    TouchableHighlight,
    View,
} from 'react-native';
import authService from './AuthService';

const styles = StyleSheet.create({
    container: {
        backgroundColor: '#F5FCFF',
        flex: 1,
        paddingTop: 60,
        alignItems: 'center',
        padding: 10,
    },
    logo: {
        width: 194,
        height: 65,
    },
    heading: {
        fontSize: 30,
        marginTop: 20,
    },
    input: {
        alignSelf: 'stretch',
        height: 50,
        marginTop: 10,
        padding: 4,
        fontSize: 18,
        borderWidth: 1,
        borderColor: '#48bbec',
    },
    button: {
        height: 50,
        backgroundColor: '#48BBEC',
        alignSelf: 'stretch',
        marginTop: 10,
        justifyContent: 'center',
    },
    buttonText: {
        fontSize: 22,
        color: '#FFF',
        alignSelf: 'center',
    },
    loader: {
        marginTop: 20,
    },
    error: {
        color: 'red',
        marginTop: 10,
    },
});

const logo = require('../images/logo.png');

class Login extends Component {

    constructor(props) {
        super(props);
        this.onLoginPressed = this.onLoginPressed.bind(this);
        this.state = {
            showProgress: false,
        };
    }

    onLoginPressed() {
        console.log(`Log in - user:${this.state.username} pass:${this.state.password}`);
        this.setState({ showProgress: true });

        authService.loginOAuth({
            username: this.state.username,
            password: this.state.password,
        }, (results) => {
            this.setState(
                // merge objects
                Object.assign({ showProgress: false }, results)
            );
            if (results.success && this.props.onLogin) {
                // callback into App.js
                this.props.onLogin();
            }
        });
    }

    render() {
        let errorCtrl = <View />;
        if (!this.state.success && this.state.badCredentials) {
            errorCtrl = (<Text style={styles.error}>
                Bad username/password!
            </Text>);
        }
        if (!this.state.success && this.state.unknownError) {
            errorCtrl = (<Text style={styles.error}>
                Unknown error ({this.state.statusCode}) !
            </Text>);
        }
        let spinnerCtrl = <View />;

        if (this.state.showProgress) {
            spinnerCtrl = (<ActivityIndicator
                animating={this.state.showProgress}
                hidesWhenStopped
                size="large"
                style={styles.loader}/>);
        }
        return (
            <View style={styles.container}>
                <Image
                    source={logo}
                    style={styles.logo} />
                <Text style={styles.heading}>
                    ContactBase Client
                </Text>
                <TextInput
                    onChangeText={(text) => this.setState({ username: text }) }
                    placeholder="username"
                    style={styles.input} />
                <TextInput
                    onChangeText={(text) => this.setState({ password: text }) }
                    placeholder="password"
                    secureTextEntry
                    style={styles.input} />
                <TouchableHighlight
                    onPress={this.onLoginPressed.bind(this) }
                    style={styles.button}>
                    <Text
                        style={styles.buttonText}>
                        Log in
                    </Text>
                </TouchableHighlight>

                {errorCtrl}

                {spinnerCtrl}

            </View>
        );
    }
}

Login.propTypes = {
    // http://ricostacruz.com/cheatsheets/react.html
    onLogin: React.PropTypes.func,
};

module.exports = Login;
