import React, { Component } from 'react';
import {
    Text,
    View,
    StyleSheet,
    ActivityIndicator,
    Image,
} from 'react-native';
import authService from './AuthService';

const styles = StyleSheet.create({
    container: {
        flex: 1,
        justifyContent: 'flex-start',
        paddingTop: 80,
        alignItems: 'center',
    },
    containerActivityIdicator: {
        flex: 1,
        justifyContent: 'center',
    },
    row: {
        flex: 1,
        flexDirection: 'row',
        padding: 20,
        alignItems: 'center',
        borderColor: '#D7D7D7',
        borderBottomWidth: 1,
    },
    detailImage: {
        height: 240,
        width: 240,
        borderRadius: 30,
    },
    detailTextName: {
        fontSize: 40,
        paddingTop: 40,
        paddingBottom: 20,
    },
    detailTextContact: {
        fontSize: 20,
        paddingTop: 2,
        paddingBottom: 2,
        paddingLeft: 6,
    },
    contactTypeImage: {
        height: 36,
        width: 36,
    },
    containerContacts: {
    },
    containerContactRow: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center',
    },
});

class PersonDetails extends Component {

    constructor(props) {
        super(props);
        this.state = {
            dataSource: null,
            showProgress: true,
            personId: props.personId,
        };
    }

    componentDidMount() {
        this.fetchData();
    }

    fetchData() {
        authService.getAuthInfo((err, authInfo) => {
            const url = `https://contacts.akaver.com/api/Persons/${this.state.personId}`;
            fetch(url, {
                headers: authInfo.header,
            })
                .then((response) => response.json())
                .then((responseData) => {
                    this.setState({
                        dataSource: responseData,
                        showProgress: false,
                    });
                });
        });
    }

    render() {
        if (this.state.showProgress) {
            return (
                <View style={styles.containerActivityIdicator}>
                    <ActivityIndicator
                        animating
                        size="large"/>
                </View>
            );
        }
        console.log(this.state);

        const contactList = this.state.dataSource.contacts.map((contact, index) =>
            <View
                key={`v${index}`}
                style={styles.containerContactRow}>
                <Image
                    key={`i${index}`}
                    source={ { uri: contact.contactType.imageUri } }
                    style={styles.contactTypeImage}/>
                <Text
                    key={`t${index}`}
                    style={styles.detailTextContact}>
                    {contact.contactValue}
                </Text>
            </View>
        );
        return (
            <View style={styles.container}>
                <Image
                    source={ { uri: this.state.dataSource.imageUri } }
                    style={styles.detailImage}/>
                <Text
                    style={styles.detailTextName}>
                    {this.state.dataSource.firstLastname}
                </Text>
                <View
                    style={styles.containerContacts}>
                    {contactList}
                </View>
            </View>
        );
    }
}

PersonDetails.propTypes = {
    personId: React.PropTypes.number,
};

module.exports = PersonDetails;
